@@ -3,20 +3,22 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 use Data::Dumper;
 use List::Util qw(shuffle max);
+use Try::Tiny;
 use Getopt::EX::Colormap qw(colorize ansi_code);
 use Text::VisualWidth::PP 0.05 'vwidth';
-use App::Greple::wordle::word_all    qw(%word_all);
+use App::Greple::wordle::word_all    qw(@word_all %word_all);
 use App::Greple::wordle::word_hidden qw(@word_hidden);
 use App::Greple::wordle::game;
+use App::Greple::wordle::util qw(uniqword);
 
 use Getopt::EX::Hashed; {
     has answer  => '   =s ' , default => $ENV{WORDLE_ANSWER} ;
     has index   => ' n =i ' , default => $ENV{WORDLE_INDEX} ;
-    has try     => '   =i ' , default => 6 ;
+    has try     => ' x =i ' , default => 6 ;
     has total   => '   =i ' , default => 30 ;
     has random  => '   !  ' , default => 0 ;
     has series  => ' s =i ' , default => 1 ;
@@ -25,15 +27,10 @@ use Getopt::EX::Hashed; {
     has result  => '   !  ' , default => 1 ;
     has correct => '   =s ' , default => "\N{U+1F389}" ; # PARTY POPPER
     has wrong   => '   =s ' , default => "\N{U+1F4A5}" ; # COLLISION SYMBOL
+    has debug   => '   !  ' ;
 }
 no Getopt::EX::Hashed;
 
-sub _days {
-    use Date::Calc qw(Delta_Days);
-    my($mday, $mon, $year, $yday) = (localtime(time))[3,4,5,7];
-    Delta_Days(2021, 6, 19, $year + 1900, $mon + 1, $mday);
-}
-
 sub parseopt {
     my $app = shift;
     my $argv = shift;
@@ -43,6 +40,12 @@ sub parseopt {
     $app;
 }
 
+sub _days {
+    use Date::Calc qw(Delta_Days);
+    my($mday, $mon, $year, $yday) = (localtime(time))[3,4,5,7];
+    Delta_Days(2021, 6, 19, $year + 1900, $mon + 1, $mday);
+}
+
 sub setup {
     my $app = shift;
     for ($app->{index}) {
@@ -51,8 +54,8 @@ sub setup {
 	$_  += _days if /^[-+]/;
     }
     if (my $answer = $app->{answer}) {
-	$app->{series} = $app->{index} = 99999;
-	$answer =~ /^[a-z]{5}$/i or die "$answer: wrong word\n";
+	$app->{index} = undef;
+	$word_all{$answer} or die "$answer: wrong word\n";
     } else {
 	if ($app->{series} > 0) {
 	    srand($app->{series});
@@ -76,8 +79,10 @@ sub patterns {
 
 sub title {
     my $app = shift;
+    my $label = 'Greple::wordle';
+    return $label if not defined $app->{index};
     sprintf('%s %s%s',
-	    'Greple::wordle',
+	    $label,
 	    $app->{series} == 0 ? '' : sprintf("%d-", $app->{series}),
 	    $app->{index});
 }
@@ -88,6 +93,10 @@ my $app = __PACKAGE__->new or die;
 my $game;
 my $interactive;
 
+sub prompt {
+    sprintf '%d: ', $game->attempt + 1;
+}
+
 sub initialize {
     my($mod, $argv) = @_;
     $app->parseopt($argv)->setup;
@@ -95,15 +104,18 @@ sub initialize {
     push @$argv, $app->patterns;
     if ($interactive = -t STDIN) {
 	push @$argv, '--interactive', ('/dev/stdin') x $app->{total};
+	select->autoflush;
+	say $app->title;
+	print prompt();
     }
-    say $app->title;
 }
 
 sub respond {
     local $_ = $_;
     my $chomped = chomp;
     print ansi_code("{CHA}{CUU}") if $chomped;
-    print ansi_code(sprintf("{CHA}{CUF(%d)}", max(8, vwidth($_) + 2)));
+    print ansi_code(sprintf("{CHA(%d)}",
+			    max(11, vwidth($_) + length(prompt()) + 2)));
     print s/(?<=.)\z/\n/r for @_;
 }
 
@@ -119,26 +131,69 @@ sub show_result {
 sub check {
     my $word = lc s/\n//r;
     if (not $word_all{$word}) {
-	respond $app->{wrong};
+	command($word) or respond $app->{wrong};
 	$_ = '';
     } else {
 	$game->try($word);
-	print ansi_code '{CUU}' if $interactive;
     }
 }
 
+sub command {
+    my $word = shift;
+    my @cmd = split ' ', $word or return;
+    my @word = @word_all;
+    state @remember;
+    $cmd[0] =~ /^u(niq)?$/ and unshift @cmd, 'hint';
+
+    for (@cmd) {
+	try {
+	    if    ($_ eq '|')   {}
+	    elsif (/^d$/)       { $app->{debug} ^= 1 }
+	    elsif (/^!!$/)      { @word = @remember }
+	    elsif (/^h(int)?$/) { @word = choose($game->hint, @word) }
+	    elsif (/^u(niq)?$/) { @word = uniqword(@word) }
+	    elsif (/^=(.+)/)    { @word = choose(includes($1), @word) }
+	    elsif (/^!(.+)/)    { @word = choose("^(?!.*[$1])", @word) }
+	    elsif (/\W/)        { @word = choose($_, @word); }
+	    else  { return }
+	    1;
+	} or return;
+    }
+    if (@word == 0) {
+	warn "No match\n";
+	return 1;
+    }
+    @remember = @word;
+    do {
+	local $, = ' ';
+	say $game->hint_color(@word);
+    };
+    1;
+}
+
+sub includes {
+    '^' . join '', map { "(?=.*$_)" } $_[0] =~ /./g;
+}
+
+sub choose {
+    my $p = shift;
+    grep /$p/, @_;
+}
+
 sub inspect {
     if ($game->solved) {
 	respond $app->{correct} x ($app->{try} - $game->attempt + 1);
 	show_result if $app->{result};
 	exit 0;
     }
-    length or return;
-    if ($game->attempt >= $app->{try}) {
-	show_answer;
-	exit 1;
+    if (length) {
+	if ($game->attempt >= $app->{try}) {
+	    show_answer;
+	    exit 1;
+	}
+	$app->{keymap} and respond $game->keymap;
     }
-    $app->{keymap} and respond $game->keymap;
+    print prompt();
 }
 
 1;
